@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -73,4 +73,4 @@ void NoteDisplayAttributeTest::shouldHaveType()
     QCOMPARE(attribute.type(), QByteArray("NoteDisplayAttribute"));
 }
 
-QTEST_MAIN(NoteDisplayAttributeTest)
+QTEST_GUILESS_MAIN(NoteDisplayAttributeTest)
