@@ -6,8 +6,7 @@
  SPDX-License-Identifier: GPL-2.0-or-later
 *******************************************************************/
 
-#ifndef KNOTE_H
-#define KNOTE_H
+#pragma once
 
 #include "knoteinterface.h"
 #include <config-knotes.h>
@@ -18,7 +17,6 @@
 #include <KXMLGUIClient>
 
 #include <QDomDocument>
-#include <QEvent>
 #include <QFrame>
 
 class KNoteButton;
@@ -33,7 +31,7 @@ class QLabel;
 class QMenu;
 class QSizeGrip;
 class QVBoxLayout;
-
+class QEvent;
 class KNote : public QFrame, virtual public KXMLGUIClient, public KNoteInterface
 {
     Q_OBJECT
@@ -153,4 +151,3 @@ private:
     QPoint mOrigPos;
 };
 
-#endif
